debugLogNhostErrorsToConsole top-level property
When true, errors will be printed to the console via Logger.root (from
the logging package). When false, no logging will take place.
Nhost uses the logging package, which means that your application can be
configured to change what is logged, and where it is logged to. If you are
configuring logging yourself, it probably makes sense to set this flag to
false.
Implementation
bool debugLogNhostErrorsToConsole = true;